<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://ays-pro.com/
 * @since             1.0.0
 * @package           Gallery_Photo_Gallery
 *
 * @wordpress-plugin
 * Plugin Name:       Gallery - Photo Gallery
 * Plugin URI:        https://ays-pro.com/index.php/wordpress/photo-gallery
 * Description:       If you want to be different and represent your photos in a cool way, then our Photo Gallery plugin is perfect for you.
 * Version:           3.3.0
 * Author:            Photo Gallery Team
 * Author URI:        https://ays-pro.com/
 * License:           GPL-2.0+
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       gallery-photo-gallery
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if( ! defined( 'AYS_GPG_BASE_URL' ) ) {
    define( 'AYS_GPG_BASE_URL', plugin_dir_url(__FILE__ ) );
}

if( ! defined( 'AYS_GPG_DIR' ) )
    define( 'AYS_GPG_DIR', plugin_dir_path( __FILE__ ) );

if( ! defined( 'AYS_GPG_ADMIN_URL' ) ) {
    define( 'AYS_GPG_ADMIN_URL', plugin_dir_url(__FILE__ ) . 'admin/' );
}


if( ! defined( 'AYS_GPG_PUBLIC_URL' ) ) {
    define( 'AYS_GPG_PUBLIC_URL', plugin_dir_url(__FILE__ ) . 'public/' );
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'AYS_GALLERY_NAME_VERSION', '3.3.0' );
define( 'AYS_GALLERY_NAME', 'gallery-photo-gallery' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-gallery-photo-gallery-activator.php
 */
function activate_gallery_photo_gallery() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-gallery-photo-gallery-activator.php';
	Gallery_Photo_Gallery_Activator::ays_gallery_db_check();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-gallery-photo-gallery-deactivator.php
 */
function deactivate_gallery_photo_gallery() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-gallery-photo-gallery-deactivator.php';
	Gallery_Photo_Gallery_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_gallery_photo_gallery' );
register_deactivation_hook( __FILE__, 'deactivate_gallery_photo_gallery' );

add_action( 'plugins_loaded', 'activate_gallery_photo_gallery' );
/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-gallery-photo-gallery.php';


/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_gallery_photo_gallery() {
    add_action( 'admin_notices', 'general_gpg_admin_notice' );
    add_action( 'admin_notices', 'enjoy_gallery_plugin' );
	$plugin = new Gallery_Photo_Gallery();
	$plugin->run();

}

function enjoy_gallery_plugin(){
    $show = get_option('gpg-rate-message');
    switch($show){
        case 'Nope':
            if(!isset($_COOKIE['ays_gpg_rate_message']) || $_COOKIE['ays_gpg_rate_message'] != true){
                ?>
                <div class="notice notice-success is-dismissible">
                    <p> <?php echo __('Enjoy our Gallery-Photo Gallery plugin? Could you please do me a BIG favor and give it a 5-star rating on', AYS_GALLERY_NAME) . '<a href="https://wordpress.org/plugins/gallery-photo-gallery/">WordPress</a>? ' . __('Just to help us spread the word and boost our motivation.', AYS_GALLERY_NAME); ?></p>
                    <form action="" method="post">
                        <ul class="ays-wp-notice-answers">
                            <li><button type="submit" name="ays-qm-rate" value="Ok" class="ays-qm-rate button"><?php echo __('Ok, you deserve it', AYS_GALLERY_NAME);?></button></li>
                            <li><button type="submit" name="ays-qm-rate" value="Nope" class="ays-qm-rate button"><?php echo __('Nope, maybe later', AYS_GALLERY_NAME);?></button></li>
                            <li><button type="submit" name="ays-qm-rate" value="Done" class="ays-qm-rate button"><?php echo __('I already did', AYS_GALLERY_NAME);?></button></li>
                        </ul>
                    </form>
                </div>
                <?php
            }
            break;
        case false:
            ?>
            <div class="notice notice-success is-dismissible">
                <p> <?php echo __('Enjoy our Gallery-Photo Gallery plugin? Could you please do me a BIG favor and give it a 5-star rating on', AYS_GALLERY_NAME) . '<a href="https://wordpress.org/plugins/gallery-photo-gallery/">WordPress</a>? ' . __('Just to help us spread the word and boost our motivation.', AYS_GALLERY_NAME); ?></p>
                <form action="" method="post">
                    <ul class="ays-wp-notice-answers">
                        <li><button type="submit" name="ays-gpg-rate" value="Ok" class="ays-gpg-rate button"><?php echo __('Ok, you deserve it', AYS_GALLERY_NAME);?></button></li>
                        <li><button type="submit" name="ays-gpg-rate" value="Nope" class="ays-gpg-rate button"><?php echo __('Nope, maybe later', AYS_GALLERY_NAME);?></button></li>
                        <li><button type="submit" name="ays-gpg-rate" value="Done" class="ays-gpg-rate button"><?php echo __('I already did', AYS_GALLERY_NAME);?></button></li>
                    </ul>
                </form>
            </div>
            <?php
            break;
        default:
            break;
    }

    if(isset($_POST['ays-gpg-rate'])){
        if($show == ''){
            add_option('gpg-rate-message', $_POST['ays-gpg-rate']);
        }else{
            update_option('gpg-rate-message', $_POST['ays-gpg-rate']);
        }
        if($_POST['ays-gpg-rate'] == 'Nope'){
            $cookie_name = 'ays_gpg_rate_message';
            $cookie_value = true;
            $cookie_expiration =  time() + 86400;
            setcookie($cookie_name, $cookie_value, $cookie_expiration, '/');
        }
        $site_url = get_option('site_url');
        $ip = gpg_get_client_ip();
        $details = json_decode(file_get_contents("http://ipinfo.io/{$ip}/json"));
        $message = $site_url. ' admin from ' . $details->city . ', ' . $details->country . ' rated ' . $_POST['ays-gpg-rate'];
        wp_mail('info@ays-pro.com', 'Gallery - Photo Gallery Rate', $message);
        wp_redirect(esc_url_raw(add_query_arg()));
    }
}

function gpg_get_client_ip() {
    $ipaddress = '';
    if (getenv('HTTP_CLIENT_IP'))
        $ipaddress = getenv('HTTP_CLIENT_IP');
    else if(getenv('HTTP_X_FORWARDED_FOR'))
        $ipaddress = getenv('HTTP_X_FORWARDED_FOR');
    else if(getenv('HTTP_X_FORWARDED'))
        $ipaddress = getenv('HTTP_X_FORWARDED');
    else if(getenv('HTTP_FORWARDED_FOR'))
        $ipaddress = getenv('HTTP_FORWARDED_FOR');
    else if(getenv('HTTP_FORWARDED'))
        $ipaddress = getenv('HTTP_FORWARDED');
    else if(getenv('REMOTE_ADDR'))
        $ipaddress = getenv('REMOTE_ADDR');
    else
        $ipaddress = 'UNKNOWN';
    return $ipaddress;
}

function general_gpg_admin_notice(){
    if ( isset($_GET['page']) && strpos($_GET['page'], AYS_GALLERY_NAME) !== false ) {
        ?>
             <div class="ays-notice-banner">
                <div class="navigation-bar">
                    <div id="navigation-container">
                        <a class="logo-container" href="https://ays-pro.com/" target="_blank">
                            <img class="logo" src="<?php echo AYS_GPG_ADMIN_URL . '/images/ays_pro.png'; ?>" alt="AYS Pro logo" title="AYS Pro logo"/>
                        </a>
                        <ul id="menu">
                            <li><a class="ays-btn" href="https://freedemo.ays-pro.com/photo-gallery-demo-free/" target="_blank">Demo</a></li>
                            <li><a class="ays-btn" href="https://ays-pro.com/index.php/wordpress/photo-gallery/" target="_blank">PRO</a></li>
                            <li><a class="ays-btn" href="https://wordpress.org/support/plugin/gallery-photo-gallery/" target="_blank">Support Chat</a></li>
                            <li><a class="ays-btn" href="https://ays-pro.com/index.php/contact/" target="_blank">Contact us</a></li>
                        </ul>
                    </div>
                </div>
             </div>
        <?php
    }
}
run_gallery_photo_gallery();
