<?php
global $ays_gallery_db_version;
$ays_gallery_db_version = '3.3.0';
/**
 * Fired during plugin activation
 *
 * @link       https://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Gallery_Photo_Gallery
 * @subpackage Gallery_Photo_Gallery/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Gallery_Photo_Gallery
 * @subpackage Gallery_Photo_Gallery/includes
 * @author     AYS Pro LLC <info@ays-pro.com>
 */

class Gallery_Photo_Gallery_Activator {

	/**
	 * Short Description. (use period)
	 *
	 * Long Description.
	 *
	 * @since    1.0.0
	 */
	public static function activate() {
        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        global $wpdb;
        global $ays_gallery_db_version;
        $installed_ver = get_option( "ays_gallery_db_version" );

        $table = $wpdb->prefix . 'ays_gallery';
        $charset_collate = $wpdb->get_charset_collate();
        if($installed_ver != $ays_gallery_db_version) {
            
            $sql = "CREATE TABLE `" . $table . "` (
                      `id`        	        INT(16)     UNSIGNED NOT NULL AUTO_INCREMENT,
                      `title`     	        VARCHAR(256)         NOT NULL,
                      `description`	        TEXT NOT NULL,
                      `images`		        TEXT NOT NULL,
                      `images_titles`       TEXT NOT NULL,
                      `images_descs`        TEXT NOT NULL,
                      `images_alts`	        TEXT NOT NULL,
                      `images_urls`         TEXT NOT NULL,
                      `width`		        INT(16) NOT NULL,
                      `height`		        INT NOT NULL,
                      `options`             TEXT NOT NULL,
                      `hover_effect`        VARCHAR(30) NOT NULL,
                      `hover_opacity`       VARCHAR(20) NOT NULL,
                      `image_sizes`         VARCHAR(50) NOT NULL,
                      `custom_css`          TEXT NOT NULL,
                      `lightbox_color`      VARCHAR(20) NOT NULL,
                      `images_orderby`      VARCHAR(20) NOT NULL,
                      `images_dates`        TEXT NOT NULL,
                      `hover_icon`          VARCHAR(20) NOT NULL,
                      `show_title`          VARCHAR(20) NOT NULL,
                      `show_title_on`       VARCHAR(20) NOT NULL,
                      `show_with_date`      VARCHAR(20) NOT NULL,
                      `images_distance`     VARCHAR(10) NOT NULL,
                      `images_loading`      VARCHAR(30) NOT NULL,
                      PRIMARY KEY (`id`)
                    )$charset_collate;";
            dbDelta( $sql );            
            update_option('ays_gallery_db_version', $ays_gallery_db_version);
        }
	}

    public static function ays_gallery_db_check() {
        global $ays_gallery_db_version;
        if ( get_site_option( 'ays_gallery_db_version' ) != $ays_gallery_db_version ) {
            self::activate();
            self::alter_tables();
        }
    }

    private static function alter_tables(){
        global $wpdb;
        $table = $wpdb->prefix . 'ays_gallery';
        
        $query = "SELECT * FROM ".$table;
        $ays_gallery_infos = $wpdb->query( $query );

        if($ays_gallery_infos == 0){

            $images = array();
            $images_titles = array();
            $images_descs = array();
            $images_urls = array();
            $images_dates = array();
            for($i=0; $i<12; $i++){
                $images_descs[] = '';
                $images_urls[] = '';
                $images_dates[] = time();
            }
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/photo-1497030855747-0fc424f89a4b-1350x900.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/photo-1493787039806-2edcbe808750-1350x900.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/photo-1422360902398-0a91ff2c1a1f-1316x920.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/photo-1414788101029-46aec67101ca-1353x899.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/photo-1504535497387-90c521ae8523-1327x914.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/MG_8142.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/MG_2780.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/MG_2354.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/MG_2050.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/MG_0976.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/MG_0551.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/04/StockSnap_ITXLIWFJTY1.jpg';
            $images_titles[] = 'Sunest in big city';
            $images_titles[] = 'Lake';
            $images_titles[] = 'City';
            $images_titles[] = 'Nature';
            $images_titles[] = 'Beautiful waterfall';
            $images_titles[] = 'Garden';
            $images_titles[] = 'Night city';
            $images_titles[] = 'Sea';
            $images_titles[] = 'Nature in mountain';
            $images_titles[] = 'Rocks';
            $images_titles[] = 'Sahara';
            $images_titles[] = 'Photograph';
            $images = implode('***', $images);
            $images_titles = implode('***', $images_titles);
            $images_descs = implode('***', $images_descs);
            $images_urls = implode('***', $images_urls);
            $images_dates = implode('***', $images_dates);

            $options = ['columns_count' => '3', 'view_type' => 'grid'];
            $option = json_encode($options);
            $query = "INSERT INTO ".$table." (title, description, images, images_titles, images_descs, images_alts, images_urls, width, height, options, hover_effect, hover_opacity, image_sizes, lightbox_color, images_orderby, images_dates) VALUES ('Grid gallery', 'Grid gallery description', '".$images."', '".$images_titles."', '".$images_descs."', '".$images_titles."', '".$images_urls."', '1200', '1000', '".$option."', 'fadeIn', '0.5', 'full_size', '#27AE60', 'noordering', '".$images_dates."')";
            $wpdb->query( $query );
            
            $options = ['columns_count' => '3', 'view_type' => 'mosaic'];
            $option = json_encode($options);
            $query = "INSERT INTO ".$table." (title, description, images, images_titles, images_descs, images_alts, images_urls, width, height, options, hover_effect, hover_opacity, image_sizes, lightbox_color, images_orderby, images_dates) VALUES ('Mosaic gallery', 'Mosaic gallery description', '".$images."', '".$images_titles."', '".$images_descs."', '".$images_titles."', '".$images_urls."', '1200', '1000', '".$option."', 'fadeIn', '0.5', 'full_size', '#27AE60', 'noordering', '".$images_dates."')";
            $wpdb->query( $query );
        }
    }

}
