<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Gallery_Photo_Gallery
 * @subpackage Gallery_Photo_Gallery/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Gallery_Photo_Gallery
 * @subpackage Gallery_Photo_Gallery/public
 * @author     AYS Pro LLC <info@ays-pro.com>
 */
class Gallery_Photo_Gallery_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gallery_Photo_Gallery_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gallery_Photo_Gallery_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_style( 'gpg-fontawesome', 'https://use.fontawesome.com/releases/v5.4.1/css/all.css', array(), $this->version, 'all');
		wp_enqueue_style( $this->plugin_name . "-lightgallery", plugin_dir_url( __FILE__ ) . 'css/lightgallery.min.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name . "-lg-transitions", plugin_dir_url( __FILE__ ) . 'css/lg-transitions.min.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/gallery-photo-gallery-public.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'jquery.mosaic.min.css', plugin_dir_url( __FILE__ ) . 'css/jquery.mosaic.min.css?v=4', array(), $this->version, 'all' );
		wp_enqueue_style( 'masonry.pkgd.css', plugin_dir_url( __FILE__ ) . 'css/masonry.pkgd.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'animate.css', plugin_dir_url( __FILE__ ) . 'css/animate.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gallery_Photo_Gallery_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gallery_Photo_Gallery_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_script( 'jquery-effects-core' );
        wp_enqueue_script( 'jquery-ui-sortable' );
        wp_enqueue_media();
        wp_enqueue_script( 'imagesloaded.min.js', 'https://unpkg.com/imagesloaded@4/imagesloaded.pkgd.min.js', array( 'jquery' ), $this->version, true );
		wp_enqueue_script( $this->plugin_name.'picturefill.min.js', plugin_dir_url( __FILE__ ) . 'js/picturefill.min.js', array( 'jquery' ), $this->version, true );
		wp_enqueue_script( $this->plugin_name.'lightgallery-all.min.js', plugin_dir_url( __FILE__ ) . 'js/lightgallery-all.min.js', array( 'jquery' ), $this->version, true );
		wp_enqueue_script( $this->plugin_name.'jquery.mousewheel.min.js', plugin_dir_url( __FILE__ ) . 'js/jquery.mousewheel.min.js', array( 'jquery' ), $this->version, true );
		wp_enqueue_script( 'jquery.mosaic.min.js', plugin_dir_url( __FILE__ ) . 'js/jquery.mosaic.min.js', array( 'jquery' ), $this->version, true );
		wp_enqueue_script( 'masonry.pkgd.min.js', plugin_dir_url( __FILE__ ) . 'js/masonry.pkgd.min.js', array( 'jquery' ), $this->version, true );
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/gallery-photo-gallery-public.js', array( 'jquery' ), $this->version, true );

	}
    
    public function ays_initialize_gallery_shortcode(){
        add_shortcode( 'gallery_p_gallery', array($this, 'ays_generate_gallery') );
    }

    public function ays_generate_gallery( $attr ){
        
        global $wpdb;
        $id = ( isset($attr['id']) ) ? absint( intval( $attr['id'] ) ) : null;

        $gallery = $this->ays_get_gallery_by_id($id);

        $width = ( isset($attr['w']) ) ? absint( intval( $attr['w'] ) ) : $gallery["width"];
        $height = ( isset($attr['h']) ) ? absint( intval( $attr['h'] ) ) : $gallery["height"];
        /*
         * Gallery global settings
         */
        $title = $gallery["title"];
        $description = $gallery["description"];
        $custom_css = ($gallery['hover_opacity'] == '' || $gallery['hover_opacity'] === false) ? '' : $gallery["custom_css"];
        $gallery_options = json_decode($gallery['options'],true);
        $hover_opacity = ($gallery['hover_opacity'] == '' || $gallery['hover_opacity'] === false) ? '0.5' : $gallery['hover_opacity'];
        $image_sizes = ($gallery['image_sizes'] == '' || $gallery['image_sizes'] === false) ? 'full_size' : $gallery['image_sizes'];
        $lightbox_color = ($gallery['lightbox_color'] == '' || $gallery['lightbox_color'] === false) ? '#27AE60' : $gallery['lightbox_color'];
        $images_orderby = ($gallery['images_orderby'] == '' || $gallery['images_orderby'] === false) ? 'noordering' : $gallery['images_orderby'];
        $ays_hover_icon = ($gallery['hover_icon'] == '' || $gallery['hover_icon'] == false) ? 'search_plus' : $gallery['hover_icon'];
        $show_title = ($gallery['show_title'] == '' || $gallery['show_title'] == false) ? '' : $gallery['show_title'];
        $show_title_on = ($gallery['show_title_on'] == '' || $gallery['show_title_on'] == false) ? 'gallery_image' : $gallery['show_title_on'];
        $show_with_date = ($gallery['show_with_date'] == '' || $gallery['show_with_date'] == false) ? '' : $gallery['show_with_date'];
        $images_distance = empty($gallery['images_distance']) ? '20' : $gallery['images_distance'];
        
        $images_loading = ($gallery['images_loading'] == '' || $gallery['images_loading'] == false) ? 'all_loaded' : $gallery['images_loading'];
        
        $images_b_radius = (!isset($gallery_options['border_radius']) ||
                            $gallery_options['border_radius'] == '' ||
                            $gallery_options['border_radius'] == false) ? '0' : $gallery_options['border_radius'];
        $ays_images_border = (!isset($gallery_options['images_border']) ||
                            $gallery_options['images_border'] == false) ? '' : $gallery_options['images_border'];
        
        $images_hover_zoom = (!isset($gallery_options['hover_zoom']) ||
                              $gallery_options['hover_zoom'] == '' ||
                              $gallery_options['hover_zoom'] == false) ? 'no' : $gallery_options['hover_zoom'];
        $show_gal_title = (!isset($gallery_options['show_gal_title'])) ? 'on' : $gallery_options['show_gal_title'];
        $show_gal_desc = (!isset($gallery_options['show_gal_desc'])) ? 'on' : $gallery_options['show_gal_desc'];
//        $lightbox_color_rgba = hexdec(trim($lightbox_color, '#'));s
        
        $ays_images_hover_effect = (!isset($gallery_options['images_hover_effect']) || 
                                    $gallery_options['images_hover_effect'] == '' ||
                                    $gallery_options['images_hover_effect'] == null) ? 'simple' : $gallery_options['images_hover_effect'];
        $ays_images_hover_dir_aware = (!isset($gallery_options['hover_dir_aware']) ||
                                      $gallery_options['hover_dir_aware'] == null ||
                                      $gallery_options['hover_dir_aware'] == "") ? "slide" : $gallery_options['hover_dir_aware'];
        
        $lightbox_color_rgba = $this->hex2rgba($lightbox_color, 0.5);
        

        /*
         * Gallery image settings
         */
        $columns        = (!isset($gallery_options['columns_count'])) ? 3 : $gallery_options['columns_count'];
        $view           = $gallery_options['view_type'];
        $images         = explode( "***", $gallery["images"]        );
        $image_titles   = explode( "***", $gallery["images_titles"] );
        $image_descs    = explode( "***", $gallery["images_descs"]  );
        $image_alts     = explode( "***", $gallery["images_alts"]   );
        $image_urls     = explode( "***", $gallery["images_urls"]   );
        
        switch($view){
            case 'grid':
                $gallery_item_class = ".ays_gallery_container_".$id." div.ays_grid_column_".$id;
                $gallery_view_selector = "#ays_grid_row_".$id;
                $gallery_lightbox_selector = "ays_grid_column_".$id;
                break;
            case 'mosaic':                        
                $gallery_item_class = ".ays_gallery_container_".$id." .ays_mosaic_column_item_".$id;
                $gallery_view_selector = "#ays_mosaic_".$id;
                $gallery_lightbox_selector = "ays_mosaic_column_item_".$id;
                break;
            case 'masonry':                        
                $gallery_item_class = ".ays_gallery_container_".$id." .ays_masonry_item_".$id;
                $gallery_view_selector = "#ays_masonry_grid_".$id;
                $gallery_lightbox_selector = "ays_masonry_item_".$id;
                break;
        }
        
        if($images_hover_zoom == "yes"){
            $hover_zoom_In = "$(this).find('img').css({'transform': 'scale(1.15)', 'transition': '.5s ease-in-out'});";
            $hover_zoom_Out = "$(this).find('img').css({'transform': 'scale(1)', 'transition': '.5s ease-in-out'});";
        }else{
            $hover_zoom_In = "";
            $hover_zoom_Out = "";
        }
        $hover_effect__simple_js = "";
        $ays_hover_dir_aware_js = "";
        if($ays_images_hover_effect == "simple"){
            $hover_effect = $gallery['hover_effect'];
            $hover_out_effect = str_replace("In", "Out", $hover_effect);
            $hover_effect__simple_js = "$('$gallery_item_class').hover(function(){
                                            $(this).find('.ays_hover_mask').css('animation-name', '".$hover_effect."');
                                            $(this).find('.ays_hover_mask').css('animation-duration', '.5s');
                                            $(this).find('.ays_hover_mask').css('opacity', '1');
                                            $hover_zoom_In
                                        }, 
                                        function(){
                                            $(this).find('.ays_hover_mask').css('animation-name', '".$hover_out_effect."');
                                            $(this).find('.ays_hover_mask').css('animation-duration', '.5s');
                                            $hover_zoom_Out
                                        });";
        }elseif($ays_images_hover_effect == "dir_aware"){
            $ays_hover_dir_aware_js = "";
            
            if($ays_images_hover_dir_aware == "slide"){
                $ays_hover_dir_aware_js .= "
                $(document).find('$gallery_item_class').hover(function(e){
                                var ays_x = e.pageX - this.offsetLeft;
                                var ays_y = e.pageY - this.offsetTop;
                                var ays_edge = ays_closestEdge(ays_x,ays_y,this.clientWidth, this.clientHeight);
                                var ays_overlay = $(this).find('.ays_hover_mask');
                                let ays_hover_dir = ays_getDirectionKey(e, e.currentTarget);
                                switch(parseInt(ays_hover_dir)) {
                                     case 0:
                                        ays_overlay.css('display', 'flex');
                                        ays_overlay.css('animation', 'slideInDown .3s');$hover_zoom_In
                                     break;
                                     case 1:
                                        ays_overlay.css('display', 'flex')
                                        ays_overlay.css('animation', 'slideInRight .3s');$hover_zoom_In
                                     break;
                                     case 2:
                                        ays_overlay.css('display', 'flex')
                                        ays_overlay.css('animation', 'slideInUp .3s');$hover_zoom_In
                                     break;
                                     case 3:
                                        ays_overlay.css('display', 'flex')
                                        ays_overlay.css('animation', 'slideInLeft .3s');$hover_zoom_In
                                     break;
                                }

                            },
                           function(e){
                                var ays_x = e.pageX - this.offsetLeft;
                                var ays_y = e.pageY - this.offsetTop;
                                var ays_edge = ays_closestEdge(ays_x,ays_y,this.clientWidth, this.clientHeight);
                                var ays_overlay = $(this).find('.ays_hover_mask');
                                let ays_hover_dir = ays_getDirectionKey(e, e.currentTarget);
                                switch(parseInt(ays_hover_dir)) {
                                     case 0:
                                        ays_overlay.css('animation', 'slideOutUp .3s');$hover_zoom_Out
                                        setTimeout( function(){ ays_overlay.css('display', 'none');}, 250);
                                     break;
                                     case 1:
                                        ays_overlay.css('animation', 'slideOutRight .3s');$hover_zoom_Out
                                        setTimeout( function(){ ays_overlay.css('display', 'none');}, 250);
                                     break;
                                     case 2:
                                        ays_overlay.css('animation', 'slideOutDown .3s');$hover_zoom_Out
                                        setTimeout( function(){ ays_overlay.css('display', 'none');}, 250);
                                     break;
                                     case 3:
                                        ays_overlay.css('animation', 'slideOutLeft .3s');$hover_zoom_Out
                                        setTimeout( function(){ ays_overlay.css('display', 'none'); }, 250);
                                     break;
                                }
                        });";
            }elseif($ays_images_hover_dir_aware == "rotate3d"){
                $ays_hover_dir_aware_js .= "
                            $(document).find('$gallery_item_class').hover(function(e){
                                let ays_x = e.pageX - this.offsetLeft;
                                let ays_y = e.pageY - this.offsetTop;
                                let ays_edge = ays_closestEdge(ays_x,ays_y,this.clientWidth, this.clientHeight);
                                let ays_overlay = $(this).find('div.ays_hover_mask');
                                let ays_hover_dir = ays_getDirectionKey(e, e.currentTarget);
                                switch(parseInt(ays_hover_dir)) {
                                     case 0:
                                        ays_overlay.css('display', 'flex');
                                        ays_overlay.attr('class', 'ays_hover_mask animated in-top');$hover_zoom_In
                                     break;
                                     case 1:
                                        ays_overlay.css('display', 'flex')
                                        ays_overlay.attr('class', 'ays_hover_mask animated in-right');$hover_zoom_In
                                     break;
                                     case 2:
                                        ays_overlay.css('display', 'flex')
                                        ays_overlay.attr('class', 'ays_hover_mask animated in-bottom');$hover_zoom_In
                                     break;
                                     case 3:
                                        ays_overlay.css('display', 'flex')
                                        ays_overlay.attr('class', 'ays_hover_mask animated in-left');$hover_zoom_In
                                     break;
                                }

                            },
                           function(e){
                                let ays_x = e.pageX - this.offsetLeft;
                                let ays_y = e.pageY - this.offsetTop;
                                let ays_edge = ays_closestEdge(ays_x,ays_y,this.clientWidth, this.clientHeight);
                                let ays_overlay = $(this).find('div.ays_hover_mask');
                                let ays_hover_dir = ays_getDirectionKey(e, e.currentTarget);
                                switch(parseInt(ays_hover_dir)) {
                                     case 0:
                                        ays_overlay.attr('class', 'ays_hover_mask animated out-top');$hover_zoom_Out
                                        setTimeout( function(){ ays_overlay.css('opacity', '0');}, 350);
                                     break;
                                     case 1:
                                        ays_overlay.attr('class', 'ays_hover_mask animated out-right');$hover_zoom_Out
                                        setTimeout( function(){ ays_overlay.css('opacity', '0');}, 350);
                                     break;
                                     case 2:
                                        ays_overlay.attr('class', 'ays_hover_mask animated out-bottom');$hover_zoom_Out
                                        setTimeout( function(){ ays_overlay.css('opacity', '0');}, 350);
                                     break;
                                     case 3:
                                        ays_overlay.attr('class', 'ays_hover_mask animated out-left');$hover_zoom_Out
                                        setTimeout( function(){ ays_overlay.css('opacity', '0'); }, 570);
                                     break;
                                }
                        });";
            }
        }
        if($gallery["images_dates"] == '' || $gallery["images_dates"] == null){
            $image_dates = [];
            for($i=0; $i < count($images); $i++){
                $image_dates[] = time();
            }
        }else{
            $image_dates = explode( "***", $gallery["images_dates"]  );
        }
        
        if($image_dates == ''){
            $image_dates = [];
            for($i=0; $i < count($images); $i++){
                $image_dates[] = time();
            }
        }
        
        switch($ays_hover_icon){
            case 'search_plus':
                $hover_icon = "<i class='fas fa-search-plus ays_hover_icon_class'></i>";
                break;
            case 'search':
                $hover_icon = "<i class='fas fa-search ays_hover_icon_class'></i>";
                break;
            case 'plus':
                $hover_icon = "<i class='fas fa-plus ays_hover_icon_class'></i>";
                break;
            case 'plus_circle':
                $hover_icon = "<i class='fas fa-plus-circle ays_hover_icon_class'></i>";
                break;
            case 'plus_square_fas': 
                $hover_icon = "<i class='fas fa-plus-square ays_hover_icon_class'></i>";
                break;
            case 'plus_square_far':
                $hover_icon = "<i class='far fa-plus-square ays_hover_icon_class'></i>";
                break;
            case 'expand':
                $hover_icon = "<i class='fas fa-expand ays_hover_icon_class'></i>";
                break;
            case 'image_fas':
                $hover_icon = "<i class='fas fa-image ays_hover_icon_class'></i>";
                break;
            case 'image_far':
                $hover_icon = "<i class='far fa-image ays_hover_icon_class'></i>";
                break;
            case 'images_fas':
                $hover_icon = "<i class='fas fa-images ays_hover_icon_class'></i>";
                break;
            case 'images_far':
                $hover_icon = "<i class='far fa-images ays_hover_icon_class'></i>";
                break;
            case 'eye_fas':
                $hover_icon = "<i class='fas fa-eye ays_hover_icon_class'></i>";
                break;
            case 'eye_far':
                $hover_icon = "<i class='far fa-eye ays_hover_icon_class'></i>";
                break;
            case 'camera_retro':
                $hover_icon = "<i class='fas fa-camera-retro ays_hover_icon_class'></i>";
                break;
            case 'camera':
                $hover_icon = "<i class='fas fa-camera ays_hover_icon_class'></i>";
                break;
            default:
                $hover_icon = "<i class='fas fa-search-plus ays_hover_icon_class'></i>";
                break;
        }
        
        switch($images_orderby){
            case 'title':
                array_multisort($image_titles, SORT_ASC, SORT_STRING, $images, $image_descs, $image_alts, $image_urls, $image_dates);
                break;
            case 'date':
                array_multisort($image_dates, SORT_ASC, SORT_NUMERIC, $images, $image_titles, $image_descs, $image_alts, $image_urls);
                break;
            case 'random':
                $images_indexes = range(0, count($images)-1);
                shuffle($images_indexes);
                array_multisort($images_indexes, $images, $image_titles, $image_descs, $image_alts, $image_urls, $image_dates);
                break;
        }
        
        $images_new     = array();
        $this_site_path = trim(get_site_url(), "https:");
        foreach($images as $i => $img){
            if(strpos(trim($img, "https:"), $this_site_path) !== false){ 
                $query = "SELECT * FROM `wp_posts` WHERE `post_type` = 'attachment' AND `guid` = '".$img."'";
                $result_img =  $wpdb->get_results( $query, "ARRAY_A" );
                $url_img = wp_get_attachment_image_src($result_img[0]['ID'], $image_sizes);
                if($url_img === false){
                   $images_new[] = $img;
                }else{
                   $images_new[] = $url_img[0];
                }
            }else{
                $images_new[] = $img;
            }
        }
                
        $images_count = count($images);
        if($columns == null || $columns == 0){
            $columns = 3;
        }
        
        if($images_loading == 'all_loaded'){
            $ays_images_all_loaded = "<div class='gpg_loader_".$id."'>
                                        <div style='width:100%;height:100%' class='lds-disk'>
                                            <div>
                                            <div></div>
                                            <div></div>
                                            </div>
                                        </div>
                                    </div>";
        }else{
            $ays_images_all_loaded = '';
        }
        
        if($images_loading == 'current_loaded'){
            $ays_gpg_lazy_load = ".progress( function( instance, image ) {                            
                                if(image.isLoaded){
                                    $(image.img).parent().find('.ays_image_loading_div').css({
                                        'opacity': '1',
                                        'animation-name': 'fadeOut',
                                        'animation-duration': '1.2s',
                                    });
                                    setTimeout(function(){                                    
                                        $(image.img).parent().find('.ays_image_loading_div').css({
                                            'display': 'none'
                                        });                                  
                                        $(image.img).parent().find('div.ays_hover_mask').css({
                                            'display': 'flex'
                                        });
                                        $(image.img).css({
                                            'opacity': '1',
                                            'display': 'block',
                                            'animation': 'fadeInUp .5s',
                                            'z-index': 10000,
                                        });
                                    },400);
                                    
                                }
                            })";
            $ays_gpg_container_display_none_js = "";
            $ays_gpg_container_display_block_js = "";
            $ays_gpg_container_error_message_js = "";
            $ays_gpg_container_css = "display: block;";
            $ays_images_lazy_loader_css = ".ays_gallery_container_".$id." .ays_image_loading_div {
                                                display: flex;
                                            }";
            $ays_gpg_lazy_load_masonry = "aysgrid.masonry('layout');";
            $ays_gpg_lazy_load_mosaic = "$(document).find('.ays_gallery_container_".$id." .mosaic_".$id."').Mosaic({
                                            innerGap: {$images_distance}
                                        });";
            $ays_gpg_lazy_load_mosaic_css = ".ays_mosaic_column_item_".$id." a>img {
                                                opacity: 0;
                                             }
                                             .ays_mosaic_column_item_".$id." a div.ays_hover_mask {
                                                display: none;
                                             }";
            
        }else{        
            $ays_gpg_lazy_load = '';
            $ays_gpg_container_display_none_js = "$('.ays_gallery_container_".$id."').css({'display': 'none'});";
            $ays_gpg_container_display_block_js = "$('.ays_gallery_container_".$id."').css({'display': 'block', 'animation-name': 'fadeIn'});";
            $ays_gpg_container_error_message_js = "$('.ays_gallery_container_".$id."').html(errorImage);";
            $ays_gpg_container_css = "display: none;";
            $ays_images_lazy_loader_css = ".ays_gallery_container_".$id." .ays_image_loading_div {
                                                display: none;
                                            }";
            $ays_gpg_lazy_load_masonry = "";
            $ays_gpg_lazy_load_mosaic = "";
            $ays_gpg_lazy_load_mosaic_css = "";
        }
        $ays_width = $width == 0 ? '100%' : $width.'px'; 
        $column_width = 100 / $columns;
        $gallery_view = $ays_images_all_loaded;
        $gallery_view .= "<script>
                            (function($){
                                'use strict';
                                $(document).ready(function(){
                                    $ays_hover_dir_aware_js
                                   var ays_gallery_containers = document.getElementsByClassName('ays_gallery_container_".$id."');
                                   var ays_gallery_container_".$id.";
                                   for(var ays_i = 0; ays_i < ays_gallery_containers.length; ays_i++){
                                       do{
                                            ays_gallery_container_".$id." = ays_gallery_containers[ays_i].parentElement.parentElement;
                                        }
                                        while(ays_gallery_container_".$id.".style.position === 'relative');
                                        ays_gallery_container_".$id.".style.position = 'static';
                                    }
                                });
                            })(jQuery);
                        </script>
                        <style>
                            
                            $ays_images_lazy_loader_css
                            
                            .ays_gallery_container_".$id." {
                                $ays_gpg_container_css
                            }
                            
                            $ays_gpg_lazy_load_mosaic_css
                            
                        </style>";
        if($show_gal_title == "on"){
            $show_gallery_title = "<h2 class='ays_gallery_title'>" . wp_unslash($title) . "</h2>";
        }else{
            $show_gallery_title = "";
        }
        if($show_gal_desc == "on"){
            $show_gallery_desc = "<h4 class='ays_gallery_description'>" . wp_unslash($description) . "</h4>";
        }else{
            $show_gallery_desc = "";
        }
        if($show_gal_title != "on" && $show_gal_desc != "on"){
            $show_gallery_head = "";
        }else{
            $show_gallery_head = "<div class='ays_gallery_header'>
                                    $show_gallery_title
                                    $show_gallery_desc
                                </div>";
        }
        $gallery_view .= "<div class='ays_gallery_container_".$id."' style='width: ".$ays_width."'>".$show_gallery_head;
        
        
        switch( $view ){
            case "mosaic":
                
                $gallery_image_sizes = '';
                $gallery_view .= "<div class='mosaic_".$id."' id='ays_mosaic_".$id."' style='clear:both;'>";

                foreach ($images_new as $key => $mosaic_column){
                    if($show_title == 'on'){
                        if($show_with_date == 'on'){
                            $ays_show_with_date = "<span>".date( "F d, Y", intval($image_dates[$key]))."</span>";
                        }else{
                            $ays_show_with_date = "";
                        }
                        $ays_show_title = "<div class='ays_image_title'>
                                                <span>".wp_unslash($image_titles[$key])."</span>
                                                $ays_show_with_date
                                             </div>";
                    }else{
                        $ays_show_title = '';
                    }

                    if($image_urls[$key] == ""){
                        $image_url = "";
                    }else{
                        $image_url = "<button type='button' data-url='".$image_urls[$key]."' class='ays_image_url'><i class='fas fa-link'></i></button>";
                    }
                    
                    if($show_title_on == 'gallery_image'){
                        $show_title_in_hover = "<div class='ays_hover_mask animated'><div>".$hover_icon.$image_url."</div></div> $ays_show_title ";
                    }elseif($show_title_on == 'image_hover'){
                        $show_title_in_hover = "<div class='ays_hover_mask animated'><div>".$hover_icon.$image_url."</div> $ays_show_title </div>";            
                    }
                    $gallery_view .= "<div class='item withImage ays_mosaic_column_item_".$id."' data-src='" . $images[$key] . "' data-sub-html='" . wp_unslash($image_descs[$key]) . "'>";
                         $gallery_view .= "<img src='" . $mosaic_column . "' alt='" . wp_unslash($image_alts[$key]) . "' title='" . wp_unslash($image_titles[$key]) . "'/>
                                        <div class='ays_image_loading_div'>
                                            <img src='".AYS_GPG_PUBLIC_URL."images/ays_flower_spinner_loader.svg'>
                                        </div>
                                         $show_title_in_hover
                                        <a href='javascript:void(0);'></a>
                                      </div>";
                }
                $gallery_view .= "</div>
                                <script>
                                    $(document).ready(function(){
                                        $hover_effect__simple_js
                                        $('.ays_mosaic_column_item_".$id." div.ays_hover_mask').find('.ays_image_url').on('click', function(e){
                                            setTimeout(function(){
                                                $(document).find('.lg-close.lg-icon').trigger('click');
                                            },450);
                                            window.open($(this).attr('data-url'),'_blank');
                                        });
                                    });
                                </script>";
                break;
            case "grid":
                $gallery_view .= "<div class='ays_grid_row' id='ays_grid_row_".$id."'>";
                foreach ($images_new as $key => $image){
                    if($show_title == 'on'){
                        if($show_with_date == 'on'){
                            $ays_show_with_date = "<span>".date( "F d, Y", intval($image_dates[$key]))."</span>";
                        }else{
                            $ays_show_with_date = "";
                        }
                        $ays_show_title = "<div class='ays_image_title'>
                                                <span>".wp_unslash($image_titles[$key])."</span>
                                                $ays_show_with_date
                                             </div>";
                    }else{
                        $ays_show_title = '';
                    }

                    if($image_urls[$key] == ""){
                        $image_url = "";
                    }else{
                        $image_url = "<button type='button' data-url='".$image_urls[$key]."' class='ays_image_url'><i class='fas fa-link'></i></button>";
                    }
                    if($show_title_on == 'gallery_image'){
                        $show_title_in_hover = "<div class='ays_hover_mask animated'><div>".$hover_icon."".$image_url."</div></div> $ays_show_title ";
                    }elseif($show_title_on == 'image_hover'){
                        $show_title_in_hover = "<div class='ays_hover_mask animated'>
                            <div>".$hover_icon."".$image_url."</div>
                            $ays_show_title 
                        </div>";            
                    }

                    $gallery_view .="<div class='ays_grid_column_".$id."' style='width: ".($column_width - 1)."%;' data-src='" . $images[$key] . "' data-sub-html='" . wp_unslash($image_descs[$key]) . "'>
                                    <img src='" . $image . "' alt='" . wp_unslash($image_alts[$key]) . "' title='" . wp_unslash($image_titles[$key]) . "'/>
                                    <div class='ays_image_loading_div'>
                                        <img src='".AYS_GPG_PUBLIC_URL."images/ays_flower_spinner_loader.svg'>
                                    </div>
                                    $show_title_in_hover
                                    <a href='javascript:void(0);'></a>
                                </div>";
                }
                $gallery_view .= "</div>  
                                <script>
                                    $(document).ready(function(){
                                        $hover_effect__simple_js
                                        $('.ays_grid_column_".$id." div.ays_hover_mask').find('.ays_image_url').on('click', function(e){
                                            setTimeout(function(){
                                                $(document).find('.lg-close.lg-icon').trigger('click');
                                            },450);
                                            window.open($(this).attr('data-url'),'_blank');
                                        });
                                    });
                                </script>";
                break;
            case "masonry":
                $gallery_view .= "<div class='ays_masonry_grid' id='ays_masonry_grid_".$id."'><div class='ays_masonry_grid-sizer'></div>";
                foreach($images_new as $key=>$image){
                    if($show_title == 'on'){
                        if($show_with_date == 'on'){
                            $ays_show_with_date = "<span>".date( "F d, Y", intval($image_dates[$key]))."</span>";
                        }else{
                            $ays_show_with_date = "";
                        }
                        $ays_show_title = "<div class='ays_image_title'>
                                                <span>".wp_unslash($image_titles[$key])."</span>
                                                $ays_show_with_date
                                             </div>";
                    }else{
                        $ays_show_title = '';
                    }

                    if($image_urls[$key] == ""){
                        $image_url = "";
                    }else{
                        $image_url = "<button type='button' data-url='".$image_urls[$key]."' class='ays_image_url'><i class='fas fa-link'></i></button>";
                    }
                    if($show_title_on == 'gallery_image'){
                        $show_title_in_hover = "<div class='ays_hover_mask animated'><div>".$hover_icon."".$image_url."</div></div> $ays_show_title ";
                    }elseif($show_title_on == 'image_hover'){
                        $show_title_in_hover = "<div class='ays_hover_mask animated'>
                            <div>".$hover_icon."".$image_url."</div>
                            $ays_show_title 
                        </div>";            
                    }

                    $gallery_view .= "<div class='ays_masonry_grid-item ays_masonry_item_".$id."' data-src='" . $images[$key] . "' data-sub-html='" . wp_unslash($image_descs[$key]) . "'>
                                <img src='". $image ."' alt='".$image_alts[$key]."' title='".$image_titles[$key]."'  style='border: solid 1px #6b6666; box-shadow: none;'>
                                <div class='ays_image_loading_div'>
                                    <img src='".AYS_GPG_PUBLIC_URL."images/ays_flower_spinner_loader.svg'>
                                </div>
                                 $show_title_in_hover
                                <a href='javascript:void(0);'></a>
                            </div>";
                }
                $gallery_view .= "</div>
                                <script>
                                $(document).ready(function(){
                                    $hover_effect__simple_js
                                    $('.ays_masonry_item_".$id." div.ays_hover_mask').find('.ays_image_url').on('click', function(e){
                                        setTimeout(function(){
                                            $(document).find('.lg-close.lg-icon').trigger('click');
                                        },450);
                                        window.open($(this).attr('data-url'),'_blank');
                                    });
                                });
                                </script>
                                ";
                break;
        }
        if($ays_images_border == "on"){
            $show_images_with_border = "border: 1px solid #000;";
            $show_mosaic_border_js = "setTimeout(function(){
                                $(document).find('.ays_gallery_container_".$id." .mosaic_".$id." .ays_mosaic_column_item_".$id."').css('border', '1px solid #000');
                            },500);";
        }else{
            $show_images_with_border = "border: none";
            $show_mosaic_border_js = "";
        }
        $gallery_view .= "</div>
            <style>
                ".htmlentities($custom_css)."
                div[class^='col-'] {
                    position: static !important;
                }
                .lg-outer {
                    z-index: 999999999999;
                }
                .ays_gallery_container_".$id." {
                    max-width: 100%;
                    transition: .5s ease-in-out;
                    animation-duration: .5s;
                    position: static!important;
                }
                .gpg_loader_".$id." {
                    display: none;
                    justify-content: center;
                    align-items: center;
                    height: 100%;
                    animation-duration: .5s;
                    transition: .5s ease-in-out;
                    margin-bottom: 20px;
                }
                
                .mosaic_".$id." img {
                    box-shadow: 0 0 0 3px #6b6666;
                }
                .mosaic_".$id." {
                    padding: 6px;
                    max-width: 100%;
                }

                .mosaic_".$id." a {
                    width: 100%;
                    height: 100%;
                }

                .ays_masonry_item_".$id."{
                    width: ".($column_width-1)."%;
                }

                .ays_masonry_item_".$id." a, .ays_masonry_item_".$id.":hover,
                .mosaic_".$id." a, .mosaic_".$id.":hover {
                   box-shadow: none;
                }
                .ays_mosaic_column_item_".$id." {
                    font-size: 0;
                    margin-bottom: 0;
                    margin-right: 0;
                    overflow: hidden;
                    perspective: 200px;
                }
                
                .ays_masonry_item_".$id." img,
                .ays_mosaic_column_item_".$id." img {
                    width: 100%;
                    max-width: 100%;
                    height: 100%;
                    margin: 0 auto;
                    object-fit: cover;
                }


                div.ays_grid_row div.ays_grid_column_".$id." {
                    height: 260px;
                    min-height: 230px;
                    background-size: cover;
                    margin-bottom: {$images_distance}px;
                    margin-right: {$images_distance}px;
                    background-position: center;
                    position: relative;
                    z-index: 2;
                    overflow: hidden;
                    transition: .5s ease-in-out;
                    perspective: 200px;
                }

                div.ays_grid_row div.ays_grid_column_".$id." > img {
                    width: 100%;
                    height: 100%;
                    object-fit: cover;
                    object-position: center center;
                }

                div.ays_masonry_grid div.ays_masonry_item_".$id." a,
                div.ays_grid_row div.ays_grid_column_".$id." a {
                    display: block;
                    z-index: 3;
                    box-shadow: none;
                }
                
                div.ays_grid_row div.ays_grid_column_".$id." a:hover{
                    box-shadow: none;
                }
                
                div.ays_masonry_grid div.ays_masonry_item_".$id.":hover,
                div.mosaic_".$id." div.ays_mosaic_column_item_".$id.":hover,
                div.ays_grid_row div.ays_grid_column_".$id.":hover{
                    cursor: pointer;
                }

                div.ays_masonry_grid div.ays_masonry_item_".$id." div.ays_hover_mask i.ays_hover_icon_class,
                div.ays_masonry_grid div.ays_masonry_item_".$id." div.ays_hover_mask .ays_hover_icon_class,
                div.ays_masonry_grid div.ays_masonry_item_".$id." div.ays_hover_mask svg,
                div.ays_grid_row div.ays_grid_column_".$id." div.ays_hover_mask i.ays_hover_icon_class,
                div.ays_grid_row div.ays_grid_column_".$id." div.ays_hover_mask .ays_hover_icon_class,
                div.ays_grid_row div.ays_grid_column_".$id." div.ays_hover_mask svg,
                .mosaic_".$id." .ays_mosaic_column_item_".$id." div.ays_hover_mask i.ays_hover_icon_class,
                .mosaic_".$id." .ays_mosaic_column_item_".$id." div.ays_hover_mask .ays_hover_icon_class,
                .mosaic_".$id." .ays_mosaic_column_item_".$id." div.ays_hover_mask svg {
                    font-size: 2.5rem !important;
                    opacity: 1 !important;
                }

                .ays_mosaic_column_".$id." {
                    width: 25%;
                    margin-right: 0;
                }
                
                .mosaic_".$id." .ays_mosaic_column_item_".$id." .ays_hover_mask svg,    
                .mosaic_".$id." .ays_mosaic_column_item_".$id." .ays_hover_mask i {    
                    font-size: 1.8rem !important;
                    opacity: 1 !important;
                }

                div.ays_masonry_item_".$id.":hover > div.ays_hover_mask,
                div.mosaic_".$id." .ays_mosaic_column_item_".$id.":hover > div.ays_hover_mask,
                div.ays_grid_row div.ays_grid_column_".$id.":hover > div.ays_hover_mask {
                    opacity: 1 !important;
                    transition: all .5s;
                }
                
                div.mosaic_".$id." div.ays_mosaic_column_item_".$id.",
                div.ays_masonry_grid div.ays_masonry_item_".$id.",
                div.ays_grid_row div.ays_grid_column_".$id." {
                    border-radius: {$images_b_radius}px;
                }

                div.ays_masonry_item_".$id." div.ays_hover_mask,
                div.mosaic_".$id." div.ays_mosaic_column_item_".$id." div.ays_hover_mask,
                div.ays_grid_row div.ays_grid_column_".$id." div.ays_hover_mask {
                    background: rgba(0,0,0,".$hover_opacity.");
                }
                
                div.ays_masonry_grid div.ays_masonry_item_".$id." div.ays_hover_mask .ays_image_url,
                div.mosaic_".$id." div.ays_mosaic_column_item_".$id." div.ays_hover_mask .ays_image_url,
                div.ays_grid_row div.ays_grid_column_".$id." div.ays_hover_mask .ays_image_url {
                    position: relative;
                    z-index: 10000000000;
                    padding: 0;
                    margin: auto;
                    background-color: transparent;
                    margin-left: 20px;
                    outline: 0;
                    border: none;
                    box-shadow: none;
                }
                
                div.mosaic_".$id." div.ays_mosaic_column_item_".$id." div.ays_hover_mask .ays_image_url i,
                div.ays_grid_row div.ays_grid_column_".$id." div.ays_hover_mask .ays_image_url i,
                div.ays_masonry_grid div.ays_masonry_item_".$id." div.ays_hover_mask .ays_image_url i,
                div.mosaic_".$id." div.ays_mosaic_column_item_".$id." div.ays_hover_mask .ays_image_url svg,
                div.ays_masonry_grid div.ays_masonry_item_".$id." div.ays_hover_mask .ays_image_url svg,
                div.ays_grid_row div.ays_grid_column_".$id." div.ays_hover_mask .ays_image_url svg {
                    padding: 0;
                    margin: auto;
                    background-color: transparent;
                    outline: 0;
                    border: none;
                    box-shadow: none;
                    font-size: 2.5rem!important;
                    color: #fff;
                }
                
                div.ays_masonry_grid div.ays_masonry_item_".$id." div.ays_hover_mask .ays_image_url:hover *,
                div.mosaic_".$id." div.ays_mosaic_column_item_".$id." div.ays_hover_mask .ays_image_url:hover *,
                div.ays_grid_row div.ays_grid_column_".$id." div.ays_hover_mask .ays_image_url:hover * {
                    color: #ccc;
                }

                div.mosaic_".$id." div.ays_mosaic_column_item_".$id." {}
                
                div.ays_masonry_grid div.ays_masonry_item_".$id.",
                div.ays_grid_row div.ays_grid_column_".$id." {
                    $show_images_with_border
                }


                div.mosaic_".$id." a,
                div.ays_masonry_item_".$id." a,
                div.ays_grid_row div.ays_grid_column_".$id." a {
                    width: 100%;
                    height: 100%;
                    position: absolute;
                    top: 0;
                    /*border: 1px solid #000;*/
                }
                
                div.ays_masonry_grid div.ays_masonry_item_".$id." .ays_image_title,
                div.mosaic_".$id." .ays_image_title,
                div.ays_grid_row div.ays_grid_column_".$id." .ays_image_title                
                {
                    background-color: ".$lightbox_color.";
                    background-color: ".$lightbox_color_rgba.";
                    z-index: 9999999;
                }
                
            </style>
            <script>
                $(document).ready(function(){
                    $ays_gpg_container_display_none_js
                    $(document).find('.gpg_loader_".$id."').css({'display': 'flex', 'animation-name': 'fadeIn'});
                    var aysgrid = $('.ays_masonry_grid').masonry({
                        percentPosition: false,
                        itemSelector: '.ays_masonry_grid-item',
                        columnWidth: '.ays_masonry_item_".$id."',
                        transitionDuration: '1s',
                        gutter: 2

                    });
                    aysgrid.masonry('layout');
                    $(document).find('.ays_gallery_container_".$id."').imagesLoaded()
                        .always( function( instance ){
                            aysgrid.masonry('layout');
                        })
                        .done( function( instance ) {
                            $ays_gpg_container_display_block_js
                            $(document).find('.gpg_loader_".$id."').css({'display': 'none', 'animation-name': 'fadeOut'});
                            $(document).find('.ays_gallery_container_".$id." .mosaic_".$id."').Mosaic({
                                innerGap: {$images_distance}
                            });
                            aysgrid.masonry('layout');
                            $show_mosaic_border_js
                        })
                        .fail( function() {
                            var errorImage = '<div><p>".__("Images does not loaded please reload page", $this->plugin_name)."</p></div>';
                            $ays_gpg_container_error_message_js
                            $ays_gpg_container_display_block_js
                            $(document).find('.gpg_loader_".$id."').css({'display': 'none', 'animation-name': 'fadeOut'});
                        })".$ays_gpg_lazy_load.";
                    $ays_gpg_lazy_load_mosaic
                    
                    
                    $(document).find('$gallery_view_selector').lightGallery({
                        selector: '.$gallery_lightbox_selector',
                        share: false,
                        hash: false,
                        fullScreen: false,
                        autoplay: false,
                        mousewheel: false,
                        keyPress: false,
                        actualSize: false,
                        pager: false,
                        download: false,
                        autoplayControls: false,
                        counter: false,
                        showThumbByDefault: false,
                    });
                });
            </script>";
        return $gallery_view;
    }

    public function ays_get_gallery_by_id( $id ) {
	    global $wpdb;

	    $sql = "SELECT * FROM {$wpdb->prefix}ays_gallery WHERE id={$id}";

	    $result = $wpdb->get_row( $sql, "ARRAY_A" );

	    return $result;
    }

    private function array_split($array, $pieces) {
        if ($pieces < 2)
            return array($array);
        $newCount = ceil(count($array)/$pieces);
        $a = array_slice($array, 0, $newCount);
        $b = $this->array_split(array_slice($array, $newCount), $pieces-1);
        return array_merge(array($a),$b);
    }
    
    private function hex2rgba( $color, $opacity = false ) {

        $default = 'rgba(39, 174, 96, 0.5)';
        /**
         * Return default if no color provided
         */
        if( empty( $color ) ) {
            return $default;
        }
        /**
         * Sanitize $color if "#" is provided
         */
        if ( $color[0] == '#' ) {
            $color = substr( $color, 1 );
        }

        /**
         * Check if color has 6 or 3 characters and get values
         */
        if ( strlen($color) == 6 ) {
            $hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
        } elseif ( strlen( $color ) == 3 ) {
            $hex = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
        } else {
            return $default;
        }

        /**
         * [$rgb description]
         * @var array
         */
        $rgb =  array_map( 'hexdec', $hex );
        /**
         * Check if opacity is set(rgba or rgb)
         */
        if( $opacity ) {
            if( abs( $opacity ) > 1 )
                $opacity = 1.0;
                $output = 'rgba( ' . implode( "," ,$rgb ) . ',' . $opacity . ' )';
        } else {
            $output = 'rgb( ' . implode( "," , $rgb ) . ' )';
        }
        /**
         * Return rgb(a) color string
         */
        return $output;
    }
}
